@@ -295,7 +295,7 @@ typedef struct cholmod_common_struct
      *	    i = 0: user-provided ordering (cholmod_analyze_p only)
      *	    i = 1: AMD (for both A and A*A')
      *	    i = 2: METIS
-ou     *	    i = 3: CHOLMOD's nested dissection (NESDIS), default parameters
+     *	    i = 3: CHOLMOD's nested dissection (NESDIS), default parameters
      *	    i = 4: natural
      *	    i = 5: NESDIS with nd_small = 20000
      *	    i = 6: NESDIS with nd_small = 4, no constrained minimum degree
@@ -911,26 +911,26 @@ typedef const cholmod_triplet* const_CHM_TR;
 
 // --------- Matrix ("M_") R ("R_") pkg  routines "re-exported": ---------------
 
-int  M_R_cholmod_start(CHM_CM);
-void M_R_cholmod_error(int status, const char *file, int line, const char *message);
-int  M_cholmod_finish(CHM_CM);
+int  cholmod_start(CHM_CM);
+void R_cholmod_error(int status, const char *file, int line, const char *message);
+int  cholmod_finish(CHM_CM);
 
-CHM_SP M_cholmod_allocate_sparse(size_t nrow, size_t ncol,
+CHM_SP cholmod_allocate_sparse(size_t nrow, size_t ncol,
 				 size_t nzmax, int sorted,
 				 int packed, int stype, int xtype,
 				 CHM_CM);
-int M_cholmod_free_factor(CHM_FR *L, CHM_CM);
-int M_cholmod_free_dense(CHM_DN *A, CHM_CM);
-int M_cholmod_free_sparse(CHM_SP *A, CHM_CM);
-int M_cholmod_free_triplet(CHM_TR *T, CHM_CM);
+int      cholmod_free_factor(CHM_FR *L, CHM_CM);
+int      cholmod_free_dense(CHM_DN *A, CHM_CM);
+int      cholmod_free_sparse(CHM_SP *A, CHM_CM);
+int      cholmod_free_triplet(CHM_TR *T, CHM_CM);
 
-long M_cholmod_nnz(const_CHM_SP, CHM_CM);
-CHM_SP M_cholmod_speye(size_t nrow, size_t ncol, int xtype, CHM_CM);
-CHM_SP M_cholmod_transpose(const_CHM_SP, int values, CHM_CM);
-int M_cholmod_sort(CHM_SP A, CHM_CM);
-CHM_SP M_cholmod_vertcat(const_CHM_SP, const_CHM_SP, int values, CHM_CM);
-CHM_SP M_cholmod_copy(const_CHM_SP, int stype, int mode, CHM_CM);
-CHM_SP M_cholmod_add(const_CHM_SP, const_CHM_SP, double alpha [2], double beta [2],
+long int cholmod_nnz(const_CHM_SP, CHM_CM);
+CHM_SP   cholmod_speye(size_t nrow, size_t ncol, int xtype, CHM_CM);
+CHM_SP   cholmod_transpose(const_CHM_SP, int values, CHM_CM);
+int      cholmod_sort(CHM_SP A, CHM_CM);
+CHM_SP   cholmod_vertcat(const_CHM_SP, const_CHM_SP, int values, CHM_CM);
+CHM_SP   cholmod_copy(const_CHM_SP, int stype, int mode, CHM_CM);
+CHM_SP   cholmod_add(const_CHM_SP, const_CHM_SP, double alpha [2], double beta [2],
 		     int values, int sorted, CHM_CM);
 
 // from ../../src/CHOLMOD/Include/cholmod_cholesky.h - line 178 :
@@ -944,41 +944,41 @@ CHM_SP M_cholmod_add(const_CHM_SP, const_CHM_SP, double alpha [2], double beta [
 #define CHOLMOD_P    7		/* permute x=Px */
 #define CHOLMOD_Pt   8		/* permute x=P'x */
 
-CHM_DN M_cholmod_solve(int, const_CHM_FR, const_CHM_DN, CHM_CM);
-CHM_SP M_cholmod_spsolve(int, const_CHM_FR, const_CHM_SP, CHM_CM);
-int M_cholmod_sdmult(const_CHM_SP, int, const double*, const double*,
+CHM_DN   cholmod_solve(int, const_CHM_FR, const_CHM_DN, CHM_CM);
+CHM_SP   cholmod_spsolve(int, const_CHM_FR, const_CHM_SP, CHM_CM);
+int      cholmod_sdmult(const_CHM_SP, int, const double*, const double*,
 		     const_CHM_DN, CHM_DN Y, CHM_CM);
-CHM_SP M_cholmod_ssmult(const_CHM_SP, const_CHM_SP, int, int, int,
+CHM_SP   cholmod_ssmult(const_CHM_SP, const_CHM_SP, int, int, int,
 			CHM_CM);
-int M_cholmod_factorize(const_CHM_SP, CHM_FR L, CHM_CM);
-int M_cholmod_factorize_p(const_CHM_SP, double *beta, int *fset,
+int      cholmod_factorize(const_CHM_SP, CHM_FR L, CHM_CM);
+int      cholmod_factorize_p(const_CHM_SP, double *beta, int *fset,
 			  size_t fsize, CHM_FR L, CHM_CM);
-CHM_SP M_cholmod_copy_sparse(const_CHM_SP, CHM_CM);
-CHM_DN M_cholmod_copy_dense(const_CHM_DN, CHM_CM);
-CHM_SP M_cholmod_aat(const_CHM_SP, int *fset, size_t fsize, int mode,
+CHM_SP   cholmod_copy_sparse(const_CHM_SP, CHM_CM);
+CHM_DN   cholmod_copy_dense(const_CHM_DN, CHM_CM);
+CHM_SP   cholmod_aat(const_CHM_SP, int *fset, size_t fsize, int mode,
 		     CHM_CM);
-int M_cholmod_band_inplace(CHM_SP A, int k1, int k2, int mode, CHM_CM);
-CHM_SP M_cholmod_add(const_CHM_SP, const_CHM_SP, double alpha[2], double beta[2],
+int      cholmod_band_inplace(CHM_SP A, int k1, int k2, int mode, CHM_CM);
+CHM_SP   cholmod_add(const_CHM_SP, const_CHM_SP, double alpha[2], double beta[2],
 		     int values, int sorted, CHM_CM);
-CHM_DN M_cholmod_allocate_dense(size_t nrow, size_t ncol, size_t d,
+CHM_DN   cholmod_allocate_dense(size_t nrow, size_t ncol, size_t d,
 				int xtype, CHM_CM);
-CHM_FR M_cholmod_analyze(const_CHM_SP, CHM_CM);
-CHM_FR M_cholmod_analyze_p(const_CHM_SP, int *Perm, int *fset,
+CHM_FR   cholmod_analyze(const_CHM_SP, CHM_CM);
+CHM_FR   cholmod_analyze_p(const_CHM_SP, int *Perm, int *fset,
 				    size_t fsize, CHM_CM);
-int M_cholmod_change_factor(int to_xtype, int to_ll, int to_super,
+int      cholmod_change_factor(int to_xtype, int to_ll, int to_super,
 			    int to_packed, int to_monotonic,
 			    CHM_FR L, CHM_CM);
-CHM_FR M_cholmod_copy_factor(const_CHM_FR, CHM_CM);
-CHM_SP M_cholmod_factor_to_sparse(const_CHM_FR, CHM_CM);
-CHM_SP M_cholmod_dense_to_sparse(const_CHM_DN, int values, CHM_CM);
-int M_cholmod_defaults (CHM_CM);
-CHM_SP M_cholmod_triplet_to_sparse(const cholmod_triplet*, int nzmax, CHM_CM);
-CHM_SP M_cholmod_submatrix(const_CHM_SP, int *rset, int rsize, int *cset,
+CHM_FR   cholmod_copy_factor(const_CHM_FR, CHM_CM);
+CHM_SP   cholmod_factor_to_sparse(const_CHM_FR, CHM_CM);
+CHM_SP   cholmod_dense_to_sparse(const_CHM_DN, int values, CHM_CM);
+int      cholmod_defaults (CHM_CM);
+CHM_SP   cholmod_triplet_to_sparse(const cholmod_triplet*, int nzmax, CHM_CM);
+CHM_SP   cholmod_submatrix(const_CHM_SP, int *rset, int rsize, int *cset,
 			   int csize, int values, int sorted,
 			   CHM_CM);
-CHM_TR M_cholmod_sparse_to_triplet(const_CHM_SP, CHM_CM);
-CHM_DN M_cholmod_sparse_to_dense(const_CHM_SP, CHM_CM);
-CHM_TR M_cholmod_allocate_triplet (size_t nrow, size_t ncol, size_t nzmax,
+CHM_TR   cholmod_sparse_to_triplet(const_CHM_SP, CHM_CM);
+CHM_DN   cholmod_sparse_to_dense(const_CHM_SP, CHM_CM);
+CHM_TR   cholmod_allocate_triplet (size_t nrow, size_t ncol, size_t nzmax,
 				   int stype, int xtype, CHM_CM);
 
 // from ../../src/CHOLMOD/Include/cholmod_matrixops.h - line 107 :
@@ -988,10 +988,10 @@ CHM_TR M_cholmod_allocate_triplet (size_t nrow, size_t ncol, size_t nzmax,
 #define CHOLMOD_COL 2		/* A = A*diag(s) */
 #define CHOLMOD_SYM 3		/* A = diag(s)*A*diag(s) */
 
-int M_cholmod_scale(const_CHM_DN, int scale, CHM_SP, CHM_CM);
+int      cholmod_scale(const_CHM_DN, int scale, CHM_SP, CHM_CM);
 
 // added in the Matrix package - the log of the determinant of the matrix that was factored
-double M_chm_factor_ldetL2(const_CHM_FR);
+double   chm_factor_ldetL2(const_CHM_FR);
 
 #ifdef	__cplusplus
 }
